@@ -40,3 +40,24 @@ def get_batch_size():
         raise ValueError("DASSANA_BATCH_SIZE environment variable is not an integer.")
 
     return int(batch_size)
+
+def get_ackID():
+    if "GCP_ACK_ID" not in os.environ:
+        raise KeyError(
+            "GCP_ACK_ID environment variable is not set."
+        )
+    return os.environ["GCP_ACK_ID"]
+
+def get_gcp_project_id():
+    if "DASSANA_GCP_PRJ_ID" not in os.environ:
+        raise KeyError(
+            "DASSANA_GCP_PRJ_ID environment variable is not set."
+        )
+    return os.environ["DASSANA_GCP_PRJ_ID"]
+
+def get_gcp_subscription_id():
+    if "GCP_SUBSCRIPTION_ID" not in os.environ:
+        raise KeyError(
+            "GCP_SUBSCRIPTION_ID environment variable is not set."
+        )
+    return os.environ["GCP_SUBSCRIPTION_ID"]
